/**
 * Copyright (c) 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes;

import java.util.Timer;

import org.ow2.petals.probes.api.KeyedProbesFactory;
import org.ow2.petals.probes.api.key.ProbeKey;
import org.ow2.petals.probes.api.probes.KeyedCounterProbe;
import org.ow2.petals.probes.api.probes.KeyedCounterProbeWithExecutionStatus;
import org.ow2.petals.probes.api.probes.KeyedGaugeProbe;
import org.ow2.petals.probes.api.probes.KeyedResponseTimeProbe;
import org.ow2.petals.probes.api.sensor.KeyedGaugeSensor;
import org.ow2.petals.probes.api.sensor.detector.KeyedCounterDefectDetector;
import org.ow2.petals.probes.impl.KeyedCounterProbeImpl;
import org.ow2.petals.probes.impl.KeyedCounterProbeWithExecutionStatusImpl;
import org.ow2.petals.probes.impl.KeyedGaugeProbeImpl;
import org.ow2.petals.probes.impl.KeyedResponseTimeProbeImpl;

/**
 * The default implementation of keyed petals probes.
 * 
 * @param <K>
 *            Type of the key identifying each counter, implementing
 *            {@link ProbeKey}.
 * @param <T>
 *            The type of measured values (internal value type).
 * @param <S>
 *            The type of value to return to client probe (external value type).
 * 
 * @author Christophe DENEUX (Linagora)
 */
public class KeyedProbesFactoryImpl<K extends ProbeKey, T extends Comparable<T>, S> implements
        KeyedProbesFactory<K, T, S> {

    @Override
    public KeyedCounterProbe<ProbeKey> createKeyedCounterProbe() {
        return new KeyedCounterProbeImpl<ProbeKey>();
    }

    @Override
    public KeyedCounterProbe<ProbeKey> createKeyedCounterProbe(
            KeyedCounterDefectDetector defectDetector) {
        return new KeyedCounterProbeImpl<ProbeKey>(defectDetector);
    }

    @Override
    public KeyedCounterProbeWithExecutionStatus<ProbeKey> createKeyedCounterProbeWithExecutionStatus() {
        return new KeyedCounterProbeWithExecutionStatusImpl<ProbeKey>();
    }

    @Override
    public KeyedCounterProbeWithExecutionStatus<ProbeKey> createKeyedCounterProbeWithExecutionStatus(
            KeyedCounterDefectDetector defectDetector) {
        return new KeyedCounterProbeWithExecutionStatusImpl<ProbeKey>(defectDetector);
    }

    @Override
    public KeyedGaugeProbe<K, T, S> createKeyedGaugeProbe(final KeyedGaugeSensor<K, T, S> sensor) {
        return new KeyedGaugeProbeImpl<K, T, S>(sensor);
    }

    @Override
    public KeyedResponseTimeProbe<K> createKeyedResponseTimeProbe(final Timer timer,
            final long samplePeriod) throws IllegalArgumentException {
        return new KeyedResponseTimeProbeImpl<K>(timer, samplePeriod);
    }

}
