/**
 * Copyright (c) 2013-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.impl;

import java.util.Timer;

import org.ow2.petals.probes.api.probes.DurationProbe;

/**
 * <p>
 * A duration or response time probe (durations are expressed in milliseconds) to probe periodically durations or
 * response times and storing:
 * <ul>
 * <li>as absolute values:
 * <ul>
 * <li>the max response time,</li>
 * <li>the avg response time,</li>
 * <li>the min response time,</li>
 * </ul>
 * </li>
 * <li>as relatives values:
 * <ul>
 * <li>the max response time,</li>
 * <li>the avg response time,</li>
 * <li>the min response time,</li>
 * <li>the 10-percentile response time: 10% of the response times are lesser than this value,</li>
 * <li>the 50-percentile response time: 50% of the response times are lesser than this value,</li>
 * <li>the 90-percentile response time: 90% of the response times are upper than this value.</li>
 * </ul>
 * </li>
 * </ul>
 * </p>
 * <p>
 * When the end of a sample occurs, relative response time values are computed with the response times collected during
 * the sample, and the absolute response time values are updated.
 * </p>
 * <p>
 * <u><b>Lifecycle</b>:</u>The relative response time values can be acceded only if the probe is started. The absolute
 * response time values can be acceded even if the probe is stopped. The collection of response times starts when the
 * probe starts. The absolute and relative response time values are reseted when the probe starts.
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class DurationProbeImpl extends AbstractDurationProbeImpl implements DurationProbe {

    public DurationProbeImpl(final Timer timer, final long samplePeriod) throws IllegalArgumentException {
        super(timer, samplePeriod);
    }

    @Override
    protected long getTimeStamp() {
        return System.currentTimeMillis();
    }
}
