/**
 * Copyright (c) 2013-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.impl.macro.detector;

import org.apache.commons.pool.impl.GenericObjectPool;
import org.ow2.petals.probes.api.sensor.detector.DefectCreator;
import org.ow2.petals.probes.api.sensor.detector.GaugeDefectDetector;

/**
 * Defect detector attached to the borrowed objects of a object pool. A defect
 * is created when no more object is available in the object pool.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class ObjectPoolBorrowedObjectsDefectDetector implements GaugeDefectDetector<Long> {

    /**
     * The factory creating the defect about the object pool exhausted.
     */
    private final DefectCreator objectPoolExhaustedDefectCreator;

    /**
     * The object pool
     */
    private GenericObjectPool<?> objectPool = null;

    /**
     * 
     * @param objectPoolExhaustedDefectCreator
     *            The factory creating and sending the defect about the object
     *            pool exhausted
     */
    public ObjectPoolBorrowedObjectsDefectDetector(
            final DefectCreator objectPoolExhaustedDefectCreator) {
        this.objectPoolExhaustedDefectCreator = objectPoolExhaustedDefectCreator;
    }

    public final void setObjectPool(final GenericObjectPool<?> objectPool) {
        this.objectPool = objectPool;
    }

    @Override
    public void detect(final Long instantValue) {
        if (this.objectPool.getNumActive() == this.objectPool.getMaxActive()) {
            // No more threads is available
            this.objectPoolExhaustedDefectCreator.createAndSend();
        }

    }
}