/**
 * Copyright (c) 2012 EBMWebsourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.key;

import java.util.ArrayList;
import java.util.List;

import org.ow2.petals.probes.api.enums.ExecutionStatus;
import org.ow2.petals.probes.api.key.ExecutionStatusProbeKey;
import org.ow2.petals.probes.api.key.ProbeKey;

/**
 * Implementation of a key needed by keyed probes including execution as
 * grouping criteria. It's a wrapper of a key implementing {@link ProbeKey} and
 * an execution status.
 * 
 * @author Christophe DENEUX (PetalsLink)
 * 
 * @param <K>
 *            Type of the initial key grouping values, implementing
 *            {@link ProbeKey}.
 */
public class ExecutionStatusProbeKeyImpl<K extends ProbeKey> implements ExecutionStatusProbeKey<K> {
    /**
     * The key implementing {@link ProbeKey}
     */
    final private K key;

    /**
     * Execution status
     */
    private ExecutionStatus executionStatus;

    public ExecutionStatusProbeKeyImpl(final K key, final ExecutionStatus executionStatus) {
        super();
        this.key = key;
        this.executionStatus = executionStatus;
    }

    @Override
    public String[] toStringArray() {
        final String[] keyAsArray = this.key.toStringArray();
        final List<String> stringAsList = new ArrayList<String>(keyAsArray.length + 1);
        for (final String item : keyAsArray) {
            stringAsList.add(item);
        }
        stringAsList.add(this.executionStatus.toString());
        return stringAsList.toArray(new String[stringAsList.size()]);
    }

    @Override
    public String toReadableString() {
        return this.key.toReadableString() + ", " + this.executionStatus.toString();
    }

    @Override
    public K getOriginalKey() {
        return this.key;
    }

    @Override
    public ExecutionStatus getExecutionStatus() {
        return this.executionStatus;
    }

    @Override
    public void setExecutionStatus(final ExecutionStatus executionStatus) {
        this.executionStatus = executionStatus;
    }

    // Generated by Eclipse
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((executionStatus == null) ? 0 : executionStatus.hashCode());
        result = prime * result + ((key == null) ? 0 : key.hashCode());
        return result;
    }

    // Generated by Eclipse
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        ExecutionStatusProbeKeyImpl other = (ExecutionStatusProbeKeyImpl) obj;
        if (executionStatus != other.executionStatus)
            return false;
        if (key == null) {
            if (other.key != null)
                return false;
        } else if (!key.equals(other.key))
            return false;
        return true;
    }

}