/**
 * Copyright (c) 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes;

import junit.framework.TestCase;

import org.junit.Test;
import org.ow2.petals.probes.api.KeyedProbesFactory;
import org.ow2.petals.probes.api.KeyedProbesFactoryBuilder;
import org.ow2.petals.probes.api.MacroProbesFactory;
import org.ow2.petals.probes.api.MacroProbesFactoryBuilder;
import org.ow2.petals.probes.api.ProbesFactory;
import org.ow2.petals.probes.api.ProbesFactoryBuilder;
import org.ow2.petals.probes.api.exceptions.MultipleProbesFactoriesFoundException;
import org.ow2.petals.probes.api.exceptions.NoProbesFactoryFoundException;
import org.ow2.petals.probes.api.key.ProbeKey;

/**
 * Unit tests about probe factory builder to load the current implementation.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ProbesFactoryBuilderTestCase {

    private class ProbeTestKey implements ProbeKey {

        @Override
        public String[] toStringArray() {
            // TODO Auto-generated method stub
            return null;
        }

        @Override
        public String toReadableString() {
            // TODO Auto-generated method stub
            return null;
        }

    }

    /**
     * <p>
     * Check that the current implementation of probes is correctly loaded using
     * the java SPI.
     * </p>
     * <p>
     * Expected results: no exception, the returned probe factory is the
     * expected one.
     * </p>
     */
    @Test
    public void testGetProbesFactory_001() {

        try {
            final ProbesFactoryBuilder<Long, Long> probesFactoryBuilder = new ProbesFactoryBuilder<Long, Long>();
            final ProbesFactory<Long, Long> probesFactory = probesFactoryBuilder
                    .getProbesFactory();

            TestCase.assertEquals("The probes factory is not the expected one !",
                    ProbesFactoryImpl.class, probesFactory.getClass());

            final KeyedProbesFactoryBuilder<ProbeTestKey, Long, Long> keyedProbesFactoryBuilder = new KeyedProbesFactoryBuilder<ProbeTestKey, Long, Long>();
            final KeyedProbesFactory<ProbeTestKey, Long, Long> keyedProbesFactory = keyedProbesFactoryBuilder
                    .getKeyedProbesFactory();

            TestCase.assertEquals("The keyed probes factory is not the expected one !",
                    KeyedProbesFactoryImpl.class, keyedProbesFactory.getClass());

            final MacroProbesFactoryBuilder macroProbesFactoryBuilder = new MacroProbesFactoryBuilder();
            final MacroProbesFactory macroProbesFactory = macroProbesFactoryBuilder
                    .getMacroProbesFactory();

            TestCase.assertEquals("The macro probes factory is not the expected one !",
                    MacroProbesFactoryImpl.class, macroProbesFactory.getClass());

        } catch (final MultipleProbesFactoriesFoundException e) {
            TestCase.fail(e.getMessage());
        } catch (final NoProbesFactoryFoundException e) {
            TestCase.fail(e.getMessage());
        }
    }

}
